<?php
/*  Copyright (c) 2014 - 2018 ArcLindon LLC, Some Rights Reserved**
 *  $Id: citem_config_example.php 499 2021-10-16 13:35:05Z bill $
 *
 *  ** Users are granted an non-exclusive, non-transferable license to copy,
 *     adapt, or modify this configuration file in support of their personal, 
 *     non-commercial use.  All other rights are reserved.
 *
 *  Changes:
 *  2021/10/13  bherndon    v13.0.0.9
 *  2018/04/05  bherndon    v11.1.2.8
 *  2018/02/25  bherndon    Added a reference test inst format
 *  2017/02/09  bherndon    v11.1.0.7
 *  2017/02/08  bherndon    Updated the instructions to include 'format' 
 *                          instructions for dates
 *  2017/02/07  bhernodn    Added information and examples for new custom
 *                          citation fields _CDSC, _CTXT, and _CDTE
 *  2016/01/29  bherndon    v10.1.0.6
 *  2016/01/29  bherndon    Now following GEDCOM conventions for custom tags
 *                          and removed 'EREF' as unnecessary
 *  2015/07/05  bherndon    v10.1.0.4
 *  2015/07/05  bherndon    Added updated notes from the old configuration file
 *  2015/07/03  bherndon    Variable renaming, removal of the source type tag
 *  2014/12/06  bherndon    v10.0.2.3
 *  2014/12/06  bherndon    Added test in format 'Census' for PAGE tags
 *  2014/12/04  bherndon    Removed extraneous line-feeds
 *  2014/11/28  bherndon    Created from bills_cfg_citation.php (trunk@70)
 */

/*  Some notes about this configuration file - 
 *
 *  The format instructions and source format specfifications that you see
 *  in this file are normal, valid PHP code, and so if you make a mistake in
 *  your specification, you'll probably encounter a syntax error when PHP 
 *  attempts to render your page.
 *  
 *  You must have a source format specification named '_default'.  If no 
 *  other specification matches the source type, this specification is used.
 *  The example at the bottom of this file has a '_default' specification
 *  corresponding to the requirements of the Chicago Manual of Style.
 *
 *  Four categories of instructions are supported that specify how the data
 *  associated with a particular source field is formatted.  These are:  
 *  'typeface', 'surround', and 'separator', and 'format'.
 *  
 *  Typefaces -
 *  
 *  Four typefaces are supported:  'plain' (the default), 'bold', 'italic', and 
 *  'uline' (i.e., underline).
 *
 *  Surrounds -
 *  
 *  Six surrounds are supported:  'none' (the default), 'quotes', 'parens', 
 *  (i.e., parenthesis), 'brackets', (i.e., square brackets), 'braces' (i.e., 
 *  curly braces), and 'angles', (i.e., angle brackets).  
 *
 *  Separators -
 *  
 *  Seven separators are supported:  'none' (the default), 'colon', 'comma',
 *  'dash', 'period', 'semi', (i.e., semi-colon), and 'space'.  With the 
 *  exception of a space and dash, all separators are followed by a space.  
 *  Dashes have spaces inserted both before and after.
 *
 *  Date Formatting -
 *
 *  Formatting for dates in citations and for custom events is supported by
 *  using a 'format' instruction that references a PHP format string as 
 *  described in the PHP manual (http://php.net/manual/en/function.date.php).
 *  When formatting instructions are used the *must precede* all other 
 *  instructions as shown in the examples.
 *  
 *  Instruction order is important.  Do you want your comma inside your quoted
 *  title?  Then your separator instruction should come before your surround
 *  instruction.  
 *
 *  Leaders and Trailers -
 *
 *  Each format spec can have a defined 'leader' and 'trailer', and these
 *  conform to the six types of separators.  So, for example, if you use 
 *  'period' as your trailer, the separator (if specified) for the last 
 *  discovered element in your citation will be omitted and the trailer 
 *  substituted.  This helps control for missing data in the citations.
 *  Leaders are pre-pended to the citation.
 *
 *  TNG Standard Source Fields - 
 *
 *  You'll notice if you peek inside the TNG database or edit a source that 
 *  there are a bunch of source fields that are considered the 'standard' 
 *  fields.  These are:  'title', 'publisher', 'author', 'repository','callnum', 
 *  'quality' (source quality), and 'actualtext'.  I support these with the 
 *  GEDCOM tags:  TITL, PUBL, AUTH, REPO, CALN, QUAY, and TEXT respectivly.  
 *  (See the mini-FAQ for an explanation of why GEDCOM.)
 *
 *  TNG Standard Citation Fields -
 *  
 *  TNG also supports a number of important fields on citations these are:
 *  'page', 'quay' (citation quality), 'note', 'description', 'citedate', and
 *  'citetext'.  These fields are handled by the GEDCOM (and custom GEDCOM) 
 *  tags:  PAGE, NOTE, QUAY, _CDSC, _CDTE, and _CTXT respectively.
 *
 *  Page Reference Fields - 
 *
 *  Page references have 5 custom GEDCOM tags that can be used to produce a 
 *  reference suitable for other genealogists to use.  These are:  _RNAM (name
 *  of the individual referenced on the page), _RAUT (an 'author' set in mod 
 *  parameters), _RTTL (the site name), _RURL (the URL of the page), and _RCDT
 *  (the current date-time).  These can be combined with any GEDCOM tags 
 *  populated from the source ID set in mod parameters to populate a page 
 *  reference.
 *
 *  A mini-FAQ:
 *
 *  Q:  Why GEDCOM tags?
 *
 *  A:  It was the only real way to level the playing field between all types
 *      of genealogy software while, at the same time, dealing with the fact 
 *      that TNG stores some information in the sources table (I assign the 
 *      expected GEDCOM tags to these pieces of data) and some data as custom
 *      events. It also helps me deal with the fact that genealogists some-
 *      times define their own tags.  For example, I use a custom 'EREF' tag
 *      that stands for 'endnote reference' (a shorthand that I use to refer to
 *      sources in notes and for naming source files).  I have one of these
 *      assigned to every source in my database and wanted them printed on the
 *      browsesource.php and individual pages.  TNG, of course, has not idea 
 *      what this source field is because from it's perspective it's just a
 *      custom source event.
 *
 *  Q:  What happens if one of the source fields I specified in a format 
 *      instructions is empty or missing?
 *
 *  A:  Citation Master treats an empty or missing source field as it simply
 *      doesn't exist in the output.  In other words, data, surrounds and 
 *      separators are simply omitted.
 */
 
//  This is a the set of format instructions that will be assigned as the 
//  '_default'
$default_format_inst = array(
  'AUTH' =>
    array(
      'typeface' => 'plain',
      'separator' => 'comma'
    ),
  'TITL' =>
    array(
      'typeface' => 'plain',
      'separator' => 'comma',
      'surround' => 'quotes',
    ),
  'PUBL' =>
    array(
      'typeface' => 'plain',
      'surround' => 'parens',
      'separator' => 'space'
    ),
  'PAGE' =>
    array(
      'typeface' => 'plain',
    )
  );

// Books and periodicals get a set of format instructions that include support
// for an editor (tag EDTR) and custom citation tags (_CTXT and _CDTE).
$editor_format_inst = array(
  'AUTH' =>
    array(
      'typeface' => 'plain',
      'separator' => 'comma'
    ),
  'EDTR' =>
    array(
      'typeface' => 'plain',
      'separator' => 'comma'
    ),
  'TITL' =>
    array(
      'typeface' => 'plain',
      'separator' => 'comma',
      'surround' => 'quotes',
    ),
  'PUBL' =>
    array(
      'typeface' => 'plain',
      'surround' => 'parens',
      'separator' => 'space'
    ),
  'PAGE' =>
    array(
      'typeface' => 'plain'
    ),
  '_CTXT' =>
    array(
      'typeface' => 'italic',
      'surround' => 'brackets',
      'separator' => 'comma'
    ),
  '_CDTE' =>
    array(
      'format' => 'F j, Y',
      'typeface' => 'italic',
      'surround' => 'angles',
      'separator' => 'comma'
    )
  );

// This set of format instructions are for page references.  Note that the 
// PUBL field must have a value in the source set in mod parameters.  Otherwise
// it is omitted.
$reference_format_inst = array(
  '_RAUT' =>
    array(
      'typeface' => 'plain',
      'separator' => 'comma'
    ),
  '_RNAM' =>
    array(
      'typeface' => 'plain',
      'surround' => 'quotes',
      'separator' => 'space'
    ),
  '_RTTL' =>
    array(
      'typeface' => 'italic',
      'separator' => 'space'
    ),
  'PUBL' =>
    array(
      'typeface' => 'plain',
      'surround' => 'parens',
      'separator' => 'comma'
    ),
  '_RCDT' =>
    array(
      'format' => 'F j, Y',
      'typeface' => 'italic',
      'surround' => 'angles',
      'separator' => 'comma'
    ),
  '_RURL' =>
    array(
      'prepend' => 'URL: ',
      'surround' => 'parens',
      'separator' => 'space'
    )
  );

//  Just a variable declaration for the array of format specifications.
//  This variable name can't change.
$citem_format_spec;

// Default source specification, used if nothing other entry matches. The 
// configuration file must have one of these.
$citem_format_spec['_default'] = array(
  'name' => '',
  'comment' => 'Default instruction style.',
  'context' => 'all',
  'trailer' => 'period',
  'tags' => $default_format_inst
);

// Source specification for type 'Book'
$citem_format_spec['Book'] = array(
  'name' => '',
  'comment' => 'Book/Periodical style.',
  'context' => 'all',
  'trailer' => 'period',
  'tags' => $editor_format_inst
);

// Source specification for type 'Periodical'
$citem_format_spec['Periodical'] = array(
  'name' => '',
  'comment' => 'Periodical style.',
  'context' => 'all',
  'trailer' => 'period',
  'tags' => $editor_format_inst
);

// Reference specification
$citem_format_spec['_reference'] = array(
  'name' => '',
  'comment' => 'Test style.',
  'context' => 'all',
  'trailer' => 'period',
  'tags' => $reference_format_inst
);


?>