<?php
/*  Copyright (c) 2014 - 2020 ArcLindon LLC, Some Rights Reserved**
 *  $Id: citem_config_lhgen.php 499 2021-10-16 13:35:05Z bill $
 *
 *  ** Users are granted an non-exclusive, non-transferable license to copy,
 *     adapt, or modify this configuration file in support of their personal, 
 *     non-commercial use.  All other rights are reserved.
 *
 *  Changes:
 *  2021/10/13  bherndon    v13.0.0.9
 *  2020/09/28  bherndon    v13.0.0.8d
 *  2020/09/28  bherndon    Update to conform with private spec on eApps
 *  2018/04/07  bherndon    v11.1.2.8
 *  2018/04/02  bherndon    Added a _reference instruction for IEEE
 *  2017/02/09  bherndon    v11.1.0.7
 *  2017/02/07  bherndon    Updated CMPL and DETA to custom tags _CMPL and 
 *                          _DETA.
 *  2016/01/29  bherndon    v10.1.0.6
 *  2016/01/29  bherndon    Now following GEDCOM conventions for custom tags
 *                          'EREF' =>  '_EREF'
 *  2015/07/05  bherndon    v10.0.2.4 and v10.1.0.4
 *  2014/12/06  bherndon    v10.0.2.3
 *  2014/12/04  bherndon    Switched to single quoted string values and added
 *                          surround specs for EREFs
 *  2014/12/04  bherndon    Removed extraneous line-feeds
 *  2014/11/13  bherndon    v10.0.2.2
 *  2014/11/12  bhenrdon    Updated copyright notice
 *  2014/08/04  bherndon    TNG 9.2.2 compatible
 *  2014/07/19  bherndon    Created
 */
 
//  This is my nominal set of format instructions, used for most of the 
//  source types I have.
$nominal_format_inst = array(
  '_EREF' =>
    array(
      'surround' => 'brackets',
      'typeface' => 'bold',
      'separator' => 'space'
    ),
  'AUTH' =>
    array(
      'typeface' => 'plain',
      'separator' => 'comma'
    ),
  'TITL' =>
    array(
      'typeface' => 'plain',
      'separator' => 'comma',
      'surround' => 'quotes',
    ),
  '_CMPL' =>
    array(
      'typeface' => 'italic',
      'separator' => 'comma'
    ),
  'PUBL' =>
    array(
      'typeface' => 'plain',
      'separator' => 'comma'
    ),
  '_DETA' =>
    array(
      'typeface' => 'plain',
    )
  );

// Books and periodicals need an editor.
$editor_format_inst = array(
  '_EREF' =>
    array(
      'surround' => 'brackets',
      'typeface' => 'bold',
      'separator' => 'space'
    ),
  'AUTH' =>
    array(
      'typeface' => 'plain',
      'separator' => 'comma'
    ),
  'EDTR' =>
    array(
      'typeface' => 'plain',
      'separator' => 'comma'
    ),
  'TITL' =>
    array(
      'typeface' => 'plain',
      'separator' => 'comma',
      'surround' => 'quotes',
    ),
  '_CMPL' =>
    array(
      'typeface' => 'italic',
      'separator' => 'comma'
    ),
  'PUBL' =>
    array(
      'typeface' => 'plain',
      'separator' => 'comma'
    ),
  '_DETA' =>
    array(
      'typeface' => 'plain',
    )
  );

// Type 'Census' get's a special format instruction set where the place name
// is used in lieu of a title.
$census_format_inst = array(
  '_EREF' =>
    array(
      'surround' => 'brackets',
      'typeface' => 'bold',
      'separator' => 'space'
    ),
  'PLAC' =>
    array(
      'typeface' => 'plain',
      'separator' => 'comma',
      'surround' => 'quotes'
    ),
  '_CMPL' =>
    array(
      'typeface' => 'italic',
      'separator' => array('comma', 'break')
    ),
  'PUBL' =>
    array(
      'typeface' => 'plain',
      'separator' => 'comma'
    ),
  '_DETA' =>
    array(
      'typeface' => 'plain',
    )
  );

//  Format instructions for the URL page reference, IEEE 'URL' format
$IEEE_reference_inst = array(
  'AUTH' => array(
    'separator' => 'period'
  ),
  '_RNAM' => array(
    'surround' => 'quotes',
    'separator' => 'comma'
  ),
  '_RTTL' => array(
    'typeface' => 'italic',
    'append' => '. [Online]',
    'separator' => 'period'
  ),
  '_RURL' => array(
    'prepend' => 'Available: ',
    'separator' => 'period'
  ),
  '_RCDT' => array(
    'format' => 'd-M-Y',
    'prepend' => 'Accessed: ',
    'surround' => 'brackets',
    'separator' => 'period'
  )
);


//  Just a variable declaration for the array of format specifications.
//  This variable name can't change.
$citem_format_spec;

$citem_format_spec['_default'] = array(
  'name' => '',
  'comment' => 'Default Lindell-Herndon Genealogy format (IEEE style).',
  'context' => 'all',
  'trailer' => 'period',
  'tags' => $nominal_format_inst
);

$citem_format_spec['_reference'] = array(
  'name' => '',
  'comment' => 'Test reference instructions (APA style).',
  'context' => 'all',
  'trailer' => 'period',
  'tags' => $IEEE_reference_inst
);

$citem_format_spec['Book'] = array(
  'name' => '',
  'comment' => 'Book/Periodical Citation Master format (IEEE style).',
  'context' => 'all',
  'trailer' => 'period',
  'tags' => $editor_format_inst
);

$citem_format_spec['Periodical'] = array(
  'name' => '',
  'comment' => 'Book/Periodical Citation Master format (IEEE style).',
  'context' => 'all',
  'trailer' => 'period',
  'tags' => $editor_format_inst
);

$citem_format_spec['Census'] = array(
  'name' => '',
  'comment' => 'Census Citation Master format (IEEE style).',
  'context' => 'all',
  'trailer' => 'period',
  'tags' => $census_format_inst
);

?>